pub struct LookupTimeZone {
pub name: String,
pub offset_minutes: i32,
}Fields
name: Stringoffset_minutes: i32Trait Implementations
Sourceimpl Archive for LookupTimeZone
impl Archive for LookupTimeZone
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedLookupTimeZone
type Archived = ArchivedLookupTimeZone
The archived representation of this type. Read more
Sourcetype Resolver = LookupTimeZoneResolver
type Resolver = LookupTimeZoneResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl BlockingArchive for LookupTimeZone
impl BlockingArchive for LookupTimeZone
Sourceimpl Debug for LookupTimeZone
impl Debug for LookupTimeZone
Sourceimpl<__D: Fallible + ?Sized> Deserialize<LookupTimeZone, __D> for Archived<LookupTimeZone>
impl<__D: Fallible + ?Sized> Deserialize<LookupTimeZone, __D> for Archived<LookupTimeZone>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<LookupTimeZone, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<LookupTimeZone, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for LookupTimeZone
impl MessageId for LookupTimeZone
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for LookupTimeZone
impl<__S: Fallible + ?Sized> Serialize<__S> for LookupTimeZone