pub struct SubscribeUseStandardTimeFormat;Trait Implementations
Sourceimpl Archive for SubscribeUseStandardTimeFormat
impl Archive for SubscribeUseStandardTimeFormat
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedSubscribeUseStandardTimeFormat
type Archived = ArchivedSubscribeUseStandardTimeFormat
The archived representation of this type. Read more
Sourceimpl Clone for SubscribeUseStandardTimeFormat
impl Clone for SubscribeUseStandardTimeFormat
Sourcefn clone(&self) -> SubscribeUseStandardTimeFormat
fn clone(&self) -> SubscribeUseStandardTimeFormat
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for SubscribeUseStandardTimeFormat
impl Default for SubscribeUseStandardTimeFormat
Sourcefn default() -> SubscribeUseStandardTimeFormat
fn default() -> SubscribeUseStandardTimeFormat
Returns the “default value” for a type. Read more
Sourceimpl<__D: Fallible + ?Sized> Deserialize<SubscribeUseStandardTimeFormat, __D> for Archived<SubscribeUseStandardTimeFormat>
impl<__D: Fallible + ?Sized> Deserialize<SubscribeUseStandardTimeFormat, __D> for Archived<SubscribeUseStandardTimeFormat>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<SubscribeUseStandardTimeFormat, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<SubscribeUseStandardTimeFormat, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl PartialEq for SubscribeUseStandardTimeFormat
impl PartialEq for SubscribeUseStandardTimeFormat
Sourcefn eq(&self, other: &SubscribeUseStandardTimeFormat) -> bool
fn eq(&self, other: &SubscribeUseStandardTimeFormat) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl ScalarSubscription for SubscribeUseStandardTimeFormat
impl ScalarSubscription for SubscribeUseStandardTimeFormat
type Event = UseStandardTimeFormat
type Error = Infallible
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for SubscribeUseStandardTimeFormat
impl<__S: Fallible + ?Sized> Serialize<__S> for SubscribeUseStandardTimeFormat
impl Copy for SubscribeUseStandardTimeFormat
impl Eq for SubscribeUseStandardTimeFormat
impl StructuralPartialEq for SubscribeUseStandardTimeFormat