pub struct WaitForOnboarding<P: CheckedPermissions>(pub SettingsApi<P>);Tuple Fields
0: SettingsApi<P>Trait Implementations
Sourceimpl<P> ArchiveEventHandler<OnboardingStatus> for WaitForOnboarding<P>
impl<P> ArchiveEventHandler<OnboardingStatus> for WaitForOnboarding<P>
fn handle( &mut self, msg: Owned<OnboardingStatus>, _sender: PID, context: &mut ServerContext<Self>, )
Sourceimpl<P> Server for WaitForOnboarding<P>
impl<P> Server for WaitForOnboarding<P>
Sourcefn on_start(&mut self, context: &mut ServerContext<Self>)
fn on_start(&mut self, context: &mut ServerContext<Self>)
Hook to do stuff with the context once the server is started.
Sourceimpl<P: CheckedPermissions> ServerMessages for WaitForOnboarding<P>
impl<P: CheckedPermissions> ServerMessages for WaitForOnboarding<P>
Sourceconst NAME: &'static str = ""
const NAME: &'static str = ""
The name of the server, as registered in the nameserver.
If empty, a random SID will be assigned and no nameserver registration happens.
Sourcefn messages() -> &'static [MessageDef<Self>] ⓘwhere
Self: Sized,
fn messages() -> &'static [MessageDef<Self>] ⓘwhere
Self: Sized,
Define the messages that are handled by this server. See
MessageDef and the
related functions.Auto Trait Implementations
impl<P> Freeze for WaitForOnboarding<P>
impl<P> RefUnwindSafe for WaitForOnboarding<P>
impl<P> Send for WaitForOnboarding<P>
impl<P> Sync for WaitForOnboarding<P>
impl<P> Unpin for WaitForOnboarding<P>
impl<P> UnwindSafe for WaitForOnboarding<P>